// Config: parse commands.yaml

// Copyright (C) 2021  Simon Ruderich
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

package config

import (
	"fmt"
	"os"
	"path/filepath"

	"gopkg.in/yaml.v2"

	"ruderich.org/simon/safcm"
)

func LoadCommands(group string) ([]*safcm.Command, error) {
	path := filepath.Join(group, "commands.yaml")

	var cmds []string
	x, err := os.ReadFile(path)
	if err != nil {
		if os.IsNotExist(err) {
			return nil, nil
		}
		return nil, err
	}
	err = yaml.UnmarshalStrict(x, &cmds)
	if err != nil {
		return nil, fmt.Errorf("%s: failed to load: %v", path, err)
	}

	var res []*safcm.Command
	for _, x := range cmds {
		res = append(res, &safcm.Command{
			OrigGroup: group,
			Cmd:       x,
		})
	}
	return res, nil
}
